@@ -1,13 +1,10 @@
 <?php
 $mode = 'sidebar';
 
-$standalone = 1;
-require_once('admin-header.php');
+require_once('admin.php');
 
-get_currentuserinfo();
-
-if ($user_level == 0)
-	die ("Cheatin' uh ?");
+if ( ! current_user_can('edit_posts') )
+	wp_die(__('Cheatin&#8217; uh?'));
 
 if ('b' == $_GET['a']) {
 
@@ -18,7 +15,7 @@ if ('b' == $_GET['a']) {
 <meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=UTF-8" />
 <link rel="stylesheet" href="wp-admin.css" type="text/css" />
 </head>
-<body
+<body>
 	<p>Posted !</p>
 	<p><a href="sidebar.php">Click here</a> to post again.</p>
 </body>
@@ -37,21 +34,21 @@ form {
 	padding: 3px;
 }
 .sidebar-categories {
-    display: block;
-    height: 6.6em;
-    overflow: auto;
-    background-color: #f4f4f4;
+	display: block;
+	height: 6.6em;
+	overflow: auto;
+	background-color: #f4f4f4;
 }
 .sidebar-categories label {
 	font-size: 10px;
-    display: block;
-    width: 90%;
+	display: block;
+	width: 90%;
 }
 </style>
 </head>
 <body id="sidebar">
-<h1 id="wphead"><a href="http://wordpress.org" rel="external">WordPress</a></h1>
-<form name="post" action="post.php" method="POST">
+<h1 id="wphead"><a href="http://wordpress.org/" rel="external">WordPress</a></h1>
+<form name="post" action="post.php" method="post">
 <div><input type="hidden" name="action" value="post" />
 <input type="hidden" name="user_ID" value="<?php echo $user_ID ?>" />
 <input type="hidden" name="mode" value="sidebar" />
@@ -68,9 +65,10 @@ Post:
 <textarea rows="8" cols="12" style="width: 100%" name="content" tabindex="2"></textarea>
 </p>
 <p>
-    <input name="saveasdraft" type="submit" id="saveasdraft" tabindex="9" value="Save as Draft" /> 
-    <input name="publish" type="submit" id="publish" tabindex="6" style="font-weight: bold;" value="Publish" /> 
-  
+	<input name="saveasdraft" type="submit" id="saveasdraft" tabindex="9" value="Save as Draft" />
+<?php if ( current_user_can('publish_posts') ) : ?>
+	<input name="publish" type="submit" id="publish" tabindex="6" style="font-weight: bold;" value="Publish" />
+<?php endif; ?>
 </p>
 </div>
 </form>
